# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/containers/v1/container_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.containers.v1 import container_pb2 as yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/containers/v1/container_service.proto',
  package='yandex.cloud.serverless.containers.v1',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containers',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=yandex/cloud/serverless/containers/v1/container_service.proto\x12%yandex.cloud.serverless.containers.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x35yandex/cloud/serverless/containers/v1/container.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x13GetContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"g\n\x15ListContainersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"w\n\x16ListContainersResponse\x12\x44\n\ncontainers\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.Container\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xce\x02\n\x16\x43reateContainerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17\x43reateContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x82\x03\n\x16UpdateContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9a\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x17UpdateContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"4\n\x16\x44\x65leteContainerRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x17\x44\x65leteContainerMetadata\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"B\n\x1bGetContainerRevisionRequest\x12#\n\x15\x63ontainer_revision_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb3\x01\n\x1eListContainersRevisionsRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x16\n\x0c\x63ontainer_id\x18\x02 \x01(\tH\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"~\n\x1fListContainersRevisionsResponse\x12\x42\n\trevisions\x18\x01 \x03(\x0b\x32/.yandex.cloud.serverless.containers.v1.Revision\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x02\n\x1e\x44\x65ployContainerRevisionRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12I\n\tresources\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12@\n\x11\x65xecution_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06<=600s\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12J\n\nimage_spec\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.ImageSpecB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x63oncurrency\x18\t \x01(\x03\"\xe8\x02\n\tImageSpec\x12\x17\n\timage_url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12?\n\x07\x63ommand\x18\x02 \x01(\x0b\x32..yandex.cloud.serverless.containers.v1.Command\x12\x39\n\x04\x61rgs\x18\x03 \x01(\x0b\x32+.yandex.cloud.serverless.containers.v1.Args\x12}\n\x0b\x65nvironment\x18\x04 \x03(\x0b\x32\x41.yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntryB%\x8a\xc8\x31\x06<=4096\xb2\xc8\x31\x17\x12\x15[a-zA-Z][a-zA-Z0-9_]*\x12\x13\n\x0bworking_dir\x18\x05 \x01(\t\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x1f\x44\x65ployContainerRevisionMetadata\x12\x1d\n\x15\x63ontainer_revision_id\x18\x01 \x01(\t\"\x96\x01\n\x1eListContainerOperationsRequest\x12\x1a\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListContainerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x94\x13\n\x10\x43ontainerService\x12\xa5\x01\n\x03Get\x12:.yandex.cloud.serverless.containers.v1.GetContainerRequest\x1a\x30.yandex.cloud.serverless.containers.v1.Container\"0\x82\xd3\xe4\x93\x02*\x12(/containers/v1/containers/{container_id}\x12\xa6\x01\n\x04List\x12<.yandex.cloud.serverless.containers.v1.ListContainersRequest\x1a=.yandex.cloud.serverless.containers.v1.ListContainersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/containers/v1/containers\x12\xb8\x01\n\x06\x43reate\x12=.yandex.cloud.serverless.containers.v1.CreateContainerRequest\x1a!.yandex.cloud.operation.Operation\"L\x82\xd3\xe4\x93\x02\x1e\"\x19/containers/v1/containers:\x01*\xb2\xd2*$\n\x17\x43reateContainerMetadata\x12\tContainer\x12\xc7\x01\n\x06Update\x12=.yandex.cloud.serverless.containers.v1.UpdateContainerRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02-2(/containers/v1/containers/{container_id}:\x01*\xb2\xd2*$\n\x17UpdateContainerMetadata\x12\tContainer\x12\xd0\x01\n\x06\x44\x65lete\x12=.yandex.cloud.serverless.containers.v1.DeleteContainerRequest\x1a!.yandex.cloud.operation.Operation\"d\x82\xd3\xe4\x93\x02**(/containers/v1/containers/{container_id}\xb2\xd2*0\n\x17\x44\x65leteContainerMetadata\x12\x15google.protobuf.Empty\x12\xd5\x01\n\x0e\x44\x65ployRevision\x12\x45.yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest\x1a!.yandex.cloud.operation.Operation\"Y\x82\xd3\xe4\x93\x02$\"\x1f/containers/v1/revisions:deploy:\x01*\xb2\xd2*+\n\x1f\x44\x65ployContainerRevisionMetadata\x12\x08Revision\x12\xbc\x01\n\x0bGetRevision\x12\x42.yandex.cloud.serverless.containers.v1.GetContainerRevisionRequest\x1a/.yandex.cloud.serverless.containers.v1.Revision\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/containers/v1/revisions/{container_revision_id}\x12\xc0\x01\n\rListRevisions\x12\x45.yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest\x1a\x46.yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/containers/v1/revisions\x12\xdc\x01\n\x0eListOperations\x12\x45.yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest\x1a\x46.yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/containers/v1/containers/{container_id}/operations\x12\xb9\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/containers/v1/containers/{resource_id}:listAccessBindings\x12\xe9\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02>\"9/containers/v1/containers/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf5\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\x82\xd3\xe4\x93\x02\x41\"</containers/v1/containers/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyB\x81\x01\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containersb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETCONTAINERREQUEST = _descriptor.Descriptor(
  name='GetContainerRequest',
  full_name='yandex.cloud.serverless.containers.v1.GetContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.GetContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=443,
)


_LISTCONTAINERSREQUEST = _descriptor.Descriptor(
  name='ListContainersRequest',
  full_name='yandex.cloud.serverless.containers.v1.ListContainersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.containers.v1.ListContainersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.containers.v1.ListContainersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.containers.v1.ListContainersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=548,
)


_LISTCONTAINERSRESPONSE = _descriptor.Descriptor(
  name='ListContainersResponse',
  full_name='yandex.cloud.serverless.containers.v1.ListContainersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='containers', full_name='yandex.cloud.serverless.containers.v1.ListContainersResponse.containers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=669,
)


_CREATECONTAINERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1006,
)

_CREATECONTAINERREQUEST = _descriptor.Descriptor(
  name='CreateContainerRequest',
  full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.containers.v1.CreateContainerRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATECONTAINERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=1006,
)


_CREATECONTAINERMETADATA = _descriptor.Descriptor(
  name='CreateContainerMetadata',
  full_name='yandex.cloud.serverless.containers.v1.CreateContainerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.CreateContainerMetadata.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1055,
)


_UPDATECONTAINERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1006,
)

_UPDATECONTAINERREQUEST = _descriptor.Descriptor(
  name='UpdateContainerRequest',
  full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECONTAINERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1444,
)


_UPDATECONTAINERMETADATA = _descriptor.Descriptor(
  name='UpdateContainerMetadata',
  full_name='yandex.cloud.serverless.containers.v1.UpdateContainerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.UpdateContainerMetadata.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1493,
)


_DELETECONTAINERREQUEST = _descriptor.Descriptor(
  name='DeleteContainerRequest',
  full_name='yandex.cloud.serverless.containers.v1.DeleteContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.DeleteContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1547,
)


_DELETECONTAINERMETADATA = _descriptor.Descriptor(
  name='DeleteContainerMetadata',
  full_name='yandex.cloud.serverless.containers.v1.DeleteContainerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.DeleteContainerMetadata.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1596,
)


_GETCONTAINERREVISIONREQUEST = _descriptor.Descriptor(
  name='GetContainerRevisionRequest',
  full_name='yandex.cloud.serverless.containers.v1.GetContainerRevisionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_revision_id', full_name='yandex.cloud.serverless.containers.v1.GetContainerRevisionRequest.container_revision_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1664,
)


_LISTCONTAINERSREVISIONSREQUEST = _descriptor.Descriptor(
  name='ListContainersRevisionsRequest',
  full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.container_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.page_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.filter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1667,
  serialized_end=1846,
)


_LISTCONTAINERSREVISIONSRESPONSE = _descriptor.Descriptor(
  name='ListContainersRevisionsResponse',
  full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='revisions', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse.revisions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1974,
)


_DEPLOYCONTAINERREVISIONREQUEST = _descriptor.Descriptor(
  name='DeployContainerRevisionRequest',
  full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.description', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.resources', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_timeout', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.execution_timeout', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=600s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.service_account_id', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_spec', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.image_spec', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest.concurrency', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2324,
)


_IMAGESPEC_ENVIRONMENTENTRY = _descriptor.Descriptor(
  name='EnvironmentEntry',
  full_name='yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2637,
  serialized_end=2687,
)

_IMAGESPEC = _descriptor.Descriptor(
  name='ImageSpec',
  full_name='yandex.cloud.serverless.containers.v1.ImageSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_url', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.image_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.args', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.environment', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=4096\262\3101\027\022\025[a-zA-Z][a-zA-Z0-9_]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='working_dir', full_name='yandex.cloud.serverless.containers.v1.ImageSpec.working_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMAGESPEC_ENVIRONMENTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2327,
  serialized_end=2687,
)


_DEPLOYCONTAINERREVISIONMETADATA = _descriptor.Descriptor(
  name='DeployContainerRevisionMetadata',
  full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_revision_id', full_name='yandex.cloud.serverless.containers.v1.DeployContainerRevisionMetadata.container_revision_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2689,
  serialized_end=2753,
)


_LISTCONTAINEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListContainerOperationsRequest',
  full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=2906,
)


_LISTCONTAINEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListContainerOperationsResponse',
  full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2908,
  serialized_end=3021,
)

_LISTCONTAINERSRESPONSE.fields_by_name['containers'].message_type = yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._CONTAINER
_CREATECONTAINERREQUEST_LABELSENTRY.containing_type = _CREATECONTAINERREQUEST
_CREATECONTAINERREQUEST.fields_by_name['labels'].message_type = _CREATECONTAINERREQUEST_LABELSENTRY
_UPDATECONTAINERREQUEST_LABELSENTRY.containing_type = _UPDATECONTAINERREQUEST
_UPDATECONTAINERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATECONTAINERREQUEST.fields_by_name['labels'].message_type = _UPDATECONTAINERREQUEST_LABELSENTRY
_LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id'].fields.append(
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['folder_id'])
_LISTCONTAINERSREVISIONSREQUEST.fields_by_name['folder_id'].containing_oneof = _LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id']
_LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id'].fields.append(
  _LISTCONTAINERSREVISIONSREQUEST.fields_by_name['container_id'])
_LISTCONTAINERSREVISIONSREQUEST.fields_by_name['container_id'].containing_oneof = _LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id']
_LISTCONTAINERSREVISIONSRESPONSE.fields_by_name['revisions'].message_type = yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._REVISION
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._RESOURCES
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['execution_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['image_spec'].message_type = _IMAGESPEC
_IMAGESPEC_ENVIRONMENTENTRY.containing_type = _IMAGESPEC
_IMAGESPEC.fields_by_name['command'].message_type = yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._COMMAND
_IMAGESPEC.fields_by_name['args'].message_type = yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._ARGS
_IMAGESPEC.fields_by_name['environment'].message_type = _IMAGESPEC_ENVIRONMENTENTRY
_LISTCONTAINEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetContainerRequest'] = _GETCONTAINERREQUEST
DESCRIPTOR.message_types_by_name['ListContainersRequest'] = _LISTCONTAINERSREQUEST
DESCRIPTOR.message_types_by_name['ListContainersResponse'] = _LISTCONTAINERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateContainerRequest'] = _CREATECONTAINERREQUEST
DESCRIPTOR.message_types_by_name['CreateContainerMetadata'] = _CREATECONTAINERMETADATA
DESCRIPTOR.message_types_by_name['UpdateContainerRequest'] = _UPDATECONTAINERREQUEST
DESCRIPTOR.message_types_by_name['UpdateContainerMetadata'] = _UPDATECONTAINERMETADATA
DESCRIPTOR.message_types_by_name['DeleteContainerRequest'] = _DELETECONTAINERREQUEST
DESCRIPTOR.message_types_by_name['DeleteContainerMetadata'] = _DELETECONTAINERMETADATA
DESCRIPTOR.message_types_by_name['GetContainerRevisionRequest'] = _GETCONTAINERREVISIONREQUEST
DESCRIPTOR.message_types_by_name['ListContainersRevisionsRequest'] = _LISTCONTAINERSREVISIONSREQUEST
DESCRIPTOR.message_types_by_name['ListContainersRevisionsResponse'] = _LISTCONTAINERSREVISIONSRESPONSE
DESCRIPTOR.message_types_by_name['DeployContainerRevisionRequest'] = _DEPLOYCONTAINERREVISIONREQUEST
DESCRIPTOR.message_types_by_name['ImageSpec'] = _IMAGESPEC
DESCRIPTOR.message_types_by_name['DeployContainerRevisionMetadata'] = _DEPLOYCONTAINERREVISIONMETADATA
DESCRIPTOR.message_types_by_name['ListContainerOperationsRequest'] = _LISTCONTAINEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListContainerOperationsResponse'] = _LISTCONTAINEROPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetContainerRequest = _reflection.GeneratedProtocolMessageType('GetContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.GetContainerRequest)
  })
_sym_db.RegisterMessage(GetContainerRequest)

ListContainersRequest = _reflection.GeneratedProtocolMessageType('ListContainersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainersRequest)
  })
_sym_db.RegisterMessage(ListContainersRequest)

ListContainersResponse = _reflection.GeneratedProtocolMessageType('ListContainersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainersResponse)
  })
_sym_db.RegisterMessage(ListContainersResponse)

CreateContainerRequest = _reflection.GeneratedProtocolMessageType('CreateContainerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECONTAINERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.CreateContainerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECONTAINERREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.CreateContainerRequest)
  })
_sym_db.RegisterMessage(CreateContainerRequest)
_sym_db.RegisterMessage(CreateContainerRequest.LabelsEntry)

CreateContainerMetadata = _reflection.GeneratedProtocolMessageType('CreateContainerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTAINERMETADATA,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.CreateContainerMetadata)
  })
_sym_db.RegisterMessage(CreateContainerMetadata)

UpdateContainerRequest = _reflection.GeneratedProtocolMessageType('UpdateContainerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONTAINERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.UpdateContainerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONTAINERREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.UpdateContainerRequest)
  })
_sym_db.RegisterMessage(UpdateContainerRequest)
_sym_db.RegisterMessage(UpdateContainerRequest.LabelsEntry)

UpdateContainerMetadata = _reflection.GeneratedProtocolMessageType('UpdateContainerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTAINERMETADATA,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.UpdateContainerMetadata)
  })
_sym_db.RegisterMessage(UpdateContainerMetadata)

DeleteContainerRequest = _reflection.GeneratedProtocolMessageType('DeleteContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTAINERREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.DeleteContainerRequest)
  })
_sym_db.RegisterMessage(DeleteContainerRequest)

DeleteContainerMetadata = _reflection.GeneratedProtocolMessageType('DeleteContainerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTAINERMETADATA,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.DeleteContainerMetadata)
  })
_sym_db.RegisterMessage(DeleteContainerMetadata)

GetContainerRevisionRequest = _reflection.GeneratedProtocolMessageType('GetContainerRevisionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERREVISIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.GetContainerRevisionRequest)
  })
_sym_db.RegisterMessage(GetContainerRevisionRequest)

ListContainersRevisionsRequest = _reflection.GeneratedProtocolMessageType('ListContainersRevisionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSREVISIONSREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainersRevisionsRequest)
  })
_sym_db.RegisterMessage(ListContainersRevisionsRequest)

ListContainersRevisionsResponse = _reflection.GeneratedProtocolMessageType('ListContainersRevisionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSREVISIONSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainersRevisionsResponse)
  })
_sym_db.RegisterMessage(ListContainersRevisionsResponse)

DeployContainerRevisionRequest = _reflection.GeneratedProtocolMessageType('DeployContainerRevisionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYCONTAINERREVISIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.DeployContainerRevisionRequest)
  })
_sym_db.RegisterMessage(DeployContainerRevisionRequest)

ImageSpec = _reflection.GeneratedProtocolMessageType('ImageSpec', (_message.Message,), {

  'EnvironmentEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMAGESPEC_ENVIRONMENTENTRY,
    '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ImageSpec.EnvironmentEntry)
    })
  ,
  'DESCRIPTOR' : _IMAGESPEC,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ImageSpec)
  })
_sym_db.RegisterMessage(ImageSpec)
_sym_db.RegisterMessage(ImageSpec.EnvironmentEntry)

DeployContainerRevisionMetadata = _reflection.GeneratedProtocolMessageType('DeployContainerRevisionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYCONTAINERREVISIONMETADATA,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.DeployContainerRevisionMetadata)
  })
_sym_db.RegisterMessage(DeployContainerRevisionMetadata)

ListContainerOperationsRequest = _reflection.GeneratedProtocolMessageType('ListContainerOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainerOperationsRequest)
  })
_sym_db.RegisterMessage(ListContainerOperationsRequest)

ListContainerOperationsResponse = _reflection.GeneratedProtocolMessageType('ListContainerOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.containers.v1.container_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.containers.v1.ListContainerOperationsResponse)
  })
_sym_db.RegisterMessage(ListContainerOperationsResponse)


DESCRIPTOR._options = None
_GETCONTAINERREQUEST.fields_by_name['container_id']._options = None
_LISTCONTAINERSREQUEST.fields_by_name['folder_id']._options = None
_CREATECONTAINERREQUEST_LABELSENTRY._options = None
_CREATECONTAINERREQUEST.fields_by_name['folder_id']._options = None
_CREATECONTAINERREQUEST.fields_by_name['name']._options = None
_CREATECONTAINERREQUEST.fields_by_name['description']._options = None
_CREATECONTAINERREQUEST.fields_by_name['labels']._options = None
_UPDATECONTAINERREQUEST_LABELSENTRY._options = None
_UPDATECONTAINERREQUEST.fields_by_name['container_id']._options = None
_UPDATECONTAINERREQUEST.fields_by_name['name']._options = None
_UPDATECONTAINERREQUEST.fields_by_name['description']._options = None
_UPDATECONTAINERREQUEST.fields_by_name['labels']._options = None
_DELETECONTAINERREQUEST.fields_by_name['container_id']._options = None
_GETCONTAINERREVISIONREQUEST.fields_by_name['container_revision_id']._options = None
_LISTCONTAINERSREVISIONSREQUEST.oneofs_by_name['id']._options = None
_LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCONTAINERSREVISIONSREQUEST.fields_by_name['page_token']._options = None
_LISTCONTAINERSREVISIONSREQUEST.fields_by_name['filter']._options = None
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['container_id']._options = None
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['resources']._options = None
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['execution_timeout']._options = None
_DEPLOYCONTAINERREVISIONREQUEST.fields_by_name['image_spec']._options = None
_IMAGESPEC_ENVIRONMENTENTRY._options = None
_IMAGESPEC.fields_by_name['image_url']._options = None
_IMAGESPEC.fields_by_name['environment']._options = None
_LISTCONTAINEROPERATIONSREQUEST.fields_by_name['container_id']._options = None
_LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTCONTAINEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTCONTAINEROPERATIONSREQUEST.fields_by_name['filter']._options = None

_CONTAINERSERVICE = _descriptor.ServiceDescriptor(
  name='ContainerService',
  full_name='yandex.cloud.serverless.containers.v1.ContainerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3024,
  serialized_end=5476,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCONTAINERREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._CONTAINER,
    serialized_options=b'\202\323\344\223\002*\022(/containers/v1/containers/{container_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.List',
    index=1,
    containing_service=None,
    input_type=_LISTCONTAINERSREQUEST,
    output_type=_LISTCONTAINERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/containers/v1/containers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATECONTAINERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036\"\031/containers/v1/containers:\001*\262\322*$\n\027CreateContainerMetadata\022\tContainer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATECONTAINERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-2(/containers/v1/containers/{container_id}:\001*\262\322*$\n\027UpdateContainerMetadata\022\tContainer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETECONTAINERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002**(/containers/v1/containers/{container_id}\262\322*0\n\027DeleteContainerMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeployRevision',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.DeployRevision',
    index=5,
    containing_service=None,
    input_type=_DEPLOYCONTAINERREVISIONREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/containers/v1/revisions:deploy:\001*\262\322*+\n\037DeployContainerRevisionMetadata\022\010Revision',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRevision',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.GetRevision',
    index=6,
    containing_service=None,
    input_type=_GETCONTAINERREVISIONREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_containers_dot_v1_dot_container__pb2._REVISION,
    serialized_options=b'\202\323\344\223\0022\0220/containers/v1/revisions/{container_revision_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRevisions',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.ListRevisions',
    index=7,
    containing_service=None,
    input_type=_LISTCONTAINERSREVISIONSREQUEST,
    output_type=_LISTCONTAINERSREVISIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/containers/v1/revisions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTCONTAINEROPERATIONSREQUEST,
    output_type=_LISTCONTAINEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/containers/v1/containers/{container_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.ListAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/containers/v1/containers/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.SetAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002>\"9/containers/v1/containers/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.serverless.containers.v1.ContainerService.UpdateAccessBindings',
    index=11,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002A\"</containers/v1/containers/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTAINERSERVICE)

DESCRIPTOR.services_by_name['ContainerService'] = _CONTAINERSERVICE

# @@protoc_insertion_point(module_scope)
